import paramiko
import sys
import time

def main(ip, pwd, lang):
    for obj in (ip, pwd, lang):
        assert isinstance(obj, str)
    pythonpath = ":/opt/aldebaran/lib/python2.7/site-packages"

    ssh = paramiko.client.SSHClient()
    ssh.set_missing_host_key_policy(paramiko.AutoAddPolicy())
    ssh.connect(ip, username="nao", password=pwd, allow_agent=False)
    ssh_stdin, ssh_stdout, ssh_stderr = ssh.exec_command("export PYTHONPATH='{}'; python ./rps/src/app.py {}".format(pythonpath, lang))
    # ssh.close()
    string = ssh_stdout.read().decode()
    return string

if __name__ == "__main__":
    main(sys.argv[1], sys.argv[2], sys.argv[3])



from setuptools import setup

def readme():
    with open('README.rst') as f:
        return f.read()

setup(name='prps',
      version='0.0.4',
      description='Connect to Pepper via ssh and run the rock paper scissors game.',
      long_description=readme(),
      url="https://github.com/D7017E/Rock-Paper-Scissors",
      author='D7017E',
      author_email="bersim-8@student.ltu.se",
      packages=['prps'],
      install_requires=[
        'paramiko',
      ],
      zip_safe=False)
      